<?php

// If this file is called directly, abort.
if (!defined( 'POSTIT_LT_VERSION' )) {
	die;
}


class postitPublic extends postitBase{
	public function run(){
		$this->initActions();
		$this->initFilters();
	}
	
	public function initActions(){
		add_action('wp', [$this, 'action_wp_loaded'], 99);
	}
	
	public function initFilters(){
	}
	
	public function action_wp_loaded(){
		$load_scripts = false;
		
		$only_woo_checkout = $this->getOption('only_woo_checkout', 0);
		
		if($this->getWoocommercePluginStatus()){
			if(!$only_woo_checkout || function_exists('is_checkout') && is_checkout()){
				$load_scripts = true;
			}
		}
		else {
			$load_scripts = true;
		}
		
		if($load_scripts){
			$this->initScripts();
		}
	}
	
	public function initScripts() {
		$api_key = $this->getOption('api_key', '');
		if($api_key == ''){
			return;
		}
		
		$api_type = $this->getOption('api_type', '');
		$api_urls = $this->getSettings('api_urls', []);
		$api_types = $this->getSettings('api_type', []);
		$version = isset($api_types[$api_type]['version']) ? $api_types[$api_type]['version'] : null;
		
		if(!isset($version, $api_urls[$version], $api_types[$api_type])){
			return;
		}
		
		wp_register_script(self::PLUGIN_NAME, $this->getPluginDirUrl(). 'static/public/js/postit.lt.'.$version.'.js', array('jquery-ui-autocomplete'), POSTIT_LT_VERSION, false);
		wp_localize_script(self::PLUGIN_NAME, 'postit_data', [
			'url' => $api_urls[$version],
			'version' => $version,
			'args' => array(
				'key' => $api_key,
				'limit' => (int)$this->getOption('limit', 10),
			),
			'config' => array(
				'prefix' => $this->getOption('prefix', ''),
				'label_sufix' => $this->getOption('label_sufix', ''),
			),
			'params' => array(
				'country' => $this->getOption('input_country', ''),
				'address' => $this->getOption('input_address', ''),
				'city' => $this->getOption('input_city', ''),
				'municipality' => $this->getOption('input_municipality', ''),
				'postcode' => $this->getOption('input_postcode', ''),
			),
		]);

		
		// Enqueued script with localized data.
		wp_enqueue_script(self::PLUGIN_NAME, '', array(), POSTIT_LT_VERSION, true);

		$wp_scripts = wp_scripts();
		$jquery_version = isset($wp_scripts->registered['jquery-ui-core']) ? $wp_scripts->registered['jquery-ui-core']->ver : '1.11.4';
		$style_url = 'https://ajax.googleapis.com/ajax/libs/jqueryui/' . $jquery_version . '/themes/smoothness/jquery-ui.css';

		wp_enqueue_style('postit-jqueryui', $style_url, false, POSTIT_LT_VERSION);
		wp_enqueue_style('postit-style', $this->getPluginDirUrl() . 'static/public/css/style.'.$version.'.css', array('postit-jqueryui'), POSTIT_LT_VERSION);
	}
}